﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;

namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task app_data_apple_app_reviews_task_post()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            var postData = new List<object>();
            // example #1 - a simple way to set a task
            // this way requires you to specify a location, a language of search, and a app_id.
            postData.Add(new
            {
                location_name = "United States",
                language_name = "English",
                app_id = "835599320"
            });
            // example #2 - a way to set a task with additional parameters
            // high priority allows us to complete a task faster, but you will be charged more credits.
            // after a task is completed, we will send a GET request to the address you specify. Instead of $id and $tag, you will receive actual values that are relevant to this task.
            postData.Add(new
            {
                location_name = "United States",
                language_name = "English",
                app_id = "835599320",
                priority = 2,
                tag = "some_string_123",
                pingback_url = "https://your-server.com/pingscript?id=$id&tag=$tag"
            });
            // example #3 - an alternative way to set a task
            // after a task is completed, we will send the results according to the address you set in the 'postback_url' field.
            postData.Add(new
            {
                location_name = "United States",
                language_name = "English",
                app_id = "835599320",
                postback_data = "advanced",
                postback_url = "https://your-server.com/postbackscript"
            });
            // POST /v3/app_data/apple/app_reviews/task_post
            var taskPostResponse = await httpClient.PostAsync("/v3/app_data/apple/app_reviews/task_post", new StringContent(JsonConvert.SerializeObject(postData)));
            var result = JsonConvert.DeserializeObject<dynamic>(await taskPostResponse.Content.ReadAsStringAsync());
            // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
            if (result.status_code == 20000)
            {
                // do something with result
                Console.WriteLine(result);
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}
