﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;
namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task backlinks_page_intersection_live()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            var postData = new List<object>();
            Dictionary<string, string> pagesDictionary = new Dictionary<string, string>
            {
                { "1", "football.com" },
                { "2", "fifa.com" }
            };
            // simple way to get a result
            postData.Add(new
            {
                targets = pagesDictionary,
                exclude_targets = new object[] {
                    "skysports.com"
                },
                limit = 5,
                order_by = new object[] { "1.rank,desc" },
                filters = new object[]
                {
                    new object[] { "2.domain_from_rank", ">", 400 },
                    "and",
                    new object[] { "1.dofollow", "=", true }
                }
            });
            // POST /v3/backlinks/page_intersection/live
            // the full list of possible parameters is available in documentation
            var taskPostResponse = await httpClient.PostAsync("/v3/backlinks/page_intersection/live", new StringContent(JsonConvert.SerializeObject(postData)));
            var result = JsonConvert.DeserializeObject<dynamic>(await taskPostResponse.Content.ReadAsStringAsync());
            // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
            if (result.status_code == 20000)
            {
                // do something with result
                Console.WriteLine(result);
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}