﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;

namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task business_data_updates_task_post()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            var postData = new List<object>();
            // example #1 - a simple way to set a task
            // this way requires you to specify a location, a language of search, and a keyword.
            postData.Add(new
            {
                language_code = "en",
                location_code = 1023191,
                keyword = "RustyBrick, Inc."
            });
            // example #2 - a way to set a task with additional parameters
            // high priority allows us to complete a task faster, but you will be charged more credits.
            // after a task is completed, we will send a GET request to the address you specify. Instead of $id and $tag, you will receive actual values that are relevant to this task.
            postData.Add(new
            {
                language_name = "English",
                location_name = "New York,New York,United States",
                keyword = "RustyBrick, Inc.",
                priority = 2,
                tag = "some_string_123",
                pingback_url = "https://your-server.com/pingscript?id=$id&tag=$tag"
            });
            // POST /v3/business_data/google/my_business_updates/task_post
            var taskPostResponse = await httpClient.PostAsync("/v3/business_data/google/my_business_updates/task_post", new StringContent(JsonConvert.SerializeObject(postData)));
            var result = JsonConvert.DeserializeObject<dynamic>(await taskPostResponse.Content.ReadAsStringAsync());
            // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
            if (result.status_code == 20000)
            {
                // do something with result
                Console.WriteLine(result);
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}