using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;
namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task content_analysis_search_live()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            var postData = new List<object>();
            Dictionary<string, string> keywordFields = new Dictionary<string, string>
            {
                { "snippet", "logitech" }
            };
            postData.Add(new
            {
                keyword = "logitech",
                keyword_fields = keywordFields,
                page_type = new[]
                {
                    "ecommerce",
                    "news",
                    "blogs",
                    "message-boards",
                    "organization"
                },
                search_mode = "as_is",
                filters = new object[]
                {
                    new object[] { "main_domain", "=", "reviewfinder.ca" }
                },
                internal_list_limit = 8,
                order_by = new object[] { "content_info.sentiment_connotations.anger,desc" },
                limit = 10
            });
            // POST /v3/content_analysis/search/live
            // the full list of possible parameters is available in documentation
            var taskPostResponse = await httpClient.PostAsync("/v3/content_analysis/search/live", new StringContent(JsonConvert.SerializeObject(postData)));
            var result = JsonConvert.DeserializeObject<dynamic>(await taskPostResponse.Content.ReadAsStringAsync());
            // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
            if (result.status_code == 20000)
            {
                // do something with result
                Console.WriteLine(result);
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}