﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;

namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task domain_analytics_technologies_aggregation_technologies_live()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            var postData = new List<object>();
            // You can set only one task at a time
            postData.Add(new
            {
                technology = "Nginx",
                keyword = "WordPress",
                filters = new object[]
                {
                    new object[] { "country_iso_code", "=", "US" },
                    "and",
                    new object[] { "domain_rank", ">", 800 }
                },
                order_by = new object[] { "groups_count,desc" },
                limit = 10
            });
            // POST /v3/domain_analytics/technologies/aggregation_technologies/live
            var taskPostResponse = await httpClient.PostAsync("/v3/domain_analytics/technologies/aggregation_technologies/live", new StringContent(JsonConvert.SerializeObject(postData)));
            var result = JsonConvert.DeserializeObject<dynamic>(await taskPostResponse.Content.ReadAsStringAsync());
            // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
            if (result.status_code == 20000)
            {
                // do something with result
                Console.WriteLine(result);
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}
