﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;

namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task keywords_data_google_task_post()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            var postData = new List<object>();
            // simple way to set a task
            postData.Add(new
            {
                location_name = "United States",
                language_name = "English",
                keywords = new[]
                {
                    "average page rpm adsense"
                }
            });
            // after a task is completed, we will send a GET request to the address you specify
            // instead of $id and $tag, you will receive actual values that are relevant to this task
            postData.Add(new
            {
                language_code = "en",
                location_code = 2840,
                keywords = new[]
                {
                    "adsense blank ads how long"
                },
                tag = "some_string_123",
                pingback_url = "https://your-server.com/pingscript?id=$id&tag=$tag"
            });
            // after a task is completed, we will send a GET request to the address you specify
            // instead of $id and $tag you will receive actual values that are relevant to this task
            postData.Add(new
            {
                location_name = "United States",
                language_name = "English",
                keywords = new[]
                {
                    "leads and prospects"
                },
                postback_url = "https://your-server.com/postbackscript"

            });
            // POST /v3/keywords_data/google_ads/search_volume/task_post
            // in addition to 'search_volume' you can also set other parameters
            // the full list of possible parameters is available in documentation
            var taskPostResponse = await httpClient.PostAsync("/v3/keywords_data/google_ads/search_volume/task_post", new StringContent(JsonConvert.SerializeObject(postData)));
            var result = JsonConvert.DeserializeObject<dynamic>(await taskPostResponse.Content.ReadAsStringAsync());
            // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
            if (result.status_code == 20000)
            {
                // do something with result
                Console.WriteLine(result);
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}
