﻿using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;

namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task keywords_data_google_trends_task_post()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            var postData = new List<object>();
            // simple way to set a task
            postData.Add(new
            {
                location_name = "United States",
                date_from = "2019-01-01",
                date_to = "2020-01-01",
                keywords = new[]
                {
                    "seo api"
                }
            });
            // after a task is completed, we will send a GET request to the address you specify
            // instead of $id and $tag, you will receive actual values that are relevant to this task
            postData.Add(new
            {
                location_name = "United States",
                date_from = "2019-01-01",
                date_to = "2020-01-01",
                type = "youtube",
                category_code = 3,
                keywords = new[]
                {
                    "seo api",
                    "rank api"
                },
                tag = "some_string_123",
                pingback_url = "https://your-server.com/pingscript?id=$id&tag=$tag"
            });
            // after a task is completed, we will send a GET request to the address you specify
            // instead of $id and $tag you will receive actual values that are relevant to this task
            postData.Add(new
            {
                location_name = "United States",
                date_from = "2019-01-01",
                date_to = "2020-01-01",
                type = "youtube",
                category_code = 3,
                keywords = new[]
                {
                    "seo api",
                    "rank api"
                },
                tag = "some_string_123",
                postback_url = "https://your-server.com/postbackscript"

            });
            // POST /v3/keywords_data/google_trends/explore/task_post
            var taskPostResponse = await httpClient.PostAsync("/v3/keywords_data/google_trends/explore/task_post", new StringContent(JsonConvert.SerializeObject(postData)));
            var result = JsonConvert.DeserializeObject<dynamic>(await taskPostResponse.Content.ReadAsStringAsync());
            // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
            if (result.status_code == 20000)
            {
                // do something with result
                Console.WriteLine(result);
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}
