﻿using Newtonsoft.Json;
using System;
using System.Net.Http;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;

namespace DataForSeoDemos
{
    public static partial class Demos
    {
        public static async Task keywords_data_task_get_by_id()
        {
            var httpClient = new HttpClient
            {
                BaseAddress = new Uri("https://api.dataforseo.com/"),
                // Instead of 'login' and 'password' use your credentials from https://app.dataforseo.com/api-dashboard
                DefaultRequestHeaders = { Authorization = new AuthenticationHeaderValue("Basic", Convert.ToBase64String(Encoding.ASCII.GetBytes("login:password"))) }
            };
            // get the task results by id
            // GET /v3/keywords_data/google/search_volume/task_get/$id
            // in addition to 'search_volume' you can also set other type parameters
            // the full list of possible parameters is available in documentation
            // use the task identifier that you recieved upon setting a task
            string id = "12021127-0696-0087-0000-e7b313697ffc";
            var taskGetResponse = await httpClient.GetAsync("/v3/keywords_data/google/search_volume/task_get/" + id);
            var result = JsonConvert.DeserializeObject<dynamic>(await taskGetResponse.Content.ReadAsStringAsync());
            if (result.tasks != null)
            {
                foreach (var taskResult in result.tasks)
                {
                    var fst = taskResult.First;
                    // you can find the full list of the response codes here https://docs.dataforseo.com/v3/appendix/errors
                    if (fst.status_code >= 40000 || fst.result == null)
                        Console.WriteLine($"error. Code: {fst.status_code} Message: {fst.status_message}");
                    else
                        // do something with result
                        Console.WriteLine(String.Join(Environment.NewLine, fst));
                }
            }
            else
                Console.WriteLine($"error. Code: {result.status_code} Message: {result.status_message}");
        }
    }
}
